/* vc_cpp */

/*
 * Problem  :   DIVIDE
 * Contest  :   UOI-2007 (Kremenchug)
 * Type     :   Solution
 * Date     :   March 30, 2007
 * Version  :   1.1
 * Author   :   Taras Galkovsky / Bogdan Rubl'ov
 * Language :   C++
 * Compiler :   VC 6.0, GCC 3.4
 * Algorithm:   Author Solution
 */
 
#include <stdio.h>
#include <utility>
#include <algorithm>
#include <math.h>
#include <assert.h>

using namespace std;

#define MAX 30
#define N(x,n) (((x)+1)%(n))
#define eps 1e-9

// structure for point handling on XY plane
struct point
{
    double x, y;
    
    point () {}
    
    point (double x, double y)
    {
        this->x = x;
        this->y = y;
    }    
};

// helper point functions
point operator+ (point a, point b)
{
    return point(a.x+b.x,a.y+b.y);
}    

point operator- (point a, point b)
{
    return point(a.x-b.x,a.y-b.y);
}    

// value of vector product of a x b
double vprod (point a, point b)
{
    return a.x*b.y - a.y*b.x;
}

// sign of vector product of a x b
// 0 - if fabs() < eps, -1 and 1 accordingly
int vprods (point a, point b)
{
    double p = vprod(a,b);
    if (p > eps) return 1;
    else if (p < -eps) return -1;
    else return 0;
}

// opening input and output files 
FILE * fin = fopen("divide.dat", "r");
FILE * fout = fopen("divide.sol", "w");

// storing polygons
int n[2];
point p[2][MAX];
int isections[2][2];        

// predicat used to verify if vectors (a,b) (c,d) do intersect
bool intersects (point a, point b, point c, point d)
{
    if (vprod(b - a, c - a) * vprod(b - a, d - a) <= 0 &&
        vprod(d - c, a - c) * vprod(d - c, b - c) <= 0)
        return true;
    return false;
}

// returns point of intersection of vectors (a,b) (c,d)
// one should previously call intersects predicate to verify this fact
point intersect (point a, point b, point c, point d)
{
    b=b-a; d=d-c;
    double D, D1, D2;
    D = b.x * (-d.y) - b.y * (-d.x);
    D1 = (c.x-a.x) * (-d.y) - (c.y-a.y) * (-d.x);
    D2 = b.x * (c.y-a.y)- b.y * (c.x-a.x);
    double x = D1/D;
//    double y = D2/D;
//    point A(a.x + x * b.x, a.y + x * b.y);
//    point B(c.x + y * d.x, c.y + y * d.y);
    return point (a.x + x * b.x, a.y + x * b.y);
}
   
int main ()
{
    int i, j, k;

    // reading input data
    for (j = 0; j < 2; ++j)
    {
        fscanf(fin, "%d", &n[j]);

		assert(n[j] >= 3); ///

        int x, y;
        for (i = 0; i < n[j]; ++i)
        {
            fscanf(fin, "%d %d", &x, &y);
			assert(abs(x) <= 1000); ///
			assert(abs(y) <= 1000); ///
            p[j][i].x = x;
            p[j][i].y = y;
        }    
    }

	/// verification, if we have convex polygons. DEBUG purpose only
	for (j = 0; j < 2; ++j)
	{
		int z = 0;
		for (i = 0; i < n[j]; ++i)
		{
			int cur = vprods(p[j][N(i,n[j])] - p[j][i], p[j][N(N(i,n[j]),n[j])] - p[j][N(i,n[j])]);
			if (!z) cur = z;
			else if (cur != 0)
				assert (cur == z);
		}
	}
	///
    

	// tries intersecting every pair of edges of given polygons
	// if they do intersect, store numbers of edges
	k = 0;
	for (i = 0; i < n[0]; ++i)
		for (j = 0; j < n[1]; ++j)
			if (intersects(
				p[0][i],
				p[0][N(i,n[0])],
                p[1][j],
                p[1][N(j,n[1])]) )
			{
				isections[0][k] = i;
				isections[1][k] = j;
				k++;
			}

	/// DEBUG purpose, verify that polygons have only 2 points of intersection
	assert(k == 2);
       
    // for two pairs of vectors, calculate 2 points of intersection
    for (i = 0; i < 2; ++i)
    {
        point res = intersect(p[0][isections[0][i]],
                              p[0][N(isections[0][i],n[0])],
                              p[1][isections[1][i]],
                              p[1][N(isections[1][i],n[1])]);
        fprintf(fout, "%0.3f %0.3f", res.x, res.y);
        if (i == 0) fprintf(fout, " ");
    }    

    fprintf(fout, "\n");

    fclose(fout);
        
    return 0;
}    
