/* gcc_cpp */

/*
 * Problem  :   Drawing
 * Contest  :   UOI-2007 (Kremenchug)
 * Type     :   Solution
 * Date     :   March 29, 2007
 * Version  :   1.0
 * Author   :   Volodymyr Tkachuk
 * Language :   C++
 * Compiler :   GCC 3.4.2
 * Algorithm:   Author Solution (Max flow with Ford-Falkerson algorithm)
 */
#include <vector>
#include <fstream>
#include <queue>
#include <algorithm>
using namespace std;

const char* inputfile  = "drawing.dat";
const char* outputfile = "drawing.sol";
const int maxN = 100;

struct edge_with_capacity{
	int target_vertex;
	int capacity;
	int reverse;
	edge_with_capacity(int Target, int Capacity, int Reverse){
		target_vertex = Target;
		capacity = Capacity;
		reverse = Reverse;
	}
};

vector<vector<edge_with_capacity> > Graph;
bool field[maxN][maxN];
int N,M,w,b,g;

void ReadData(){
	ifstream in(inputfile);
	in>>N>>M>>w>>b>>g;
	char c;
	for(int i=0; i<N; ++i)
		for(int j=0; j<M; ++j){
			in>>c;
			field[i][j]=(c=='W');
		}
	in.close();
}

void WriteData(int answer){
	ofstream out(outputfile);
	out<<answer<<endl;
	out.close();
}

inline int vertexNum(int i, int j){
	return 2+i*M+j;
}

void ConnectVertexes(int v1, int v2, int c1, int c2){
	edge_with_capacity e1(v2,c1,(int)Graph[v2].size()), e2(v1,c2,(int)Graph[v1].size());
	Graph[v1].push_back(e1);
	Graph[v2].push_back(e2);
}

void BuildGraph(){
	Graph.assign(N*M+2, vector<edge_with_capacity>() );
	for(int i =0; i<N; ++i)
		for(int j = 0; j<M; ++j){
			if (field[i][j])
				ConnectVertexes(vertexNum(i,j),1,b,0);
			else
				ConnectVertexes(0,vertexNum(i,j),w,0);
			if (i<N-1)
				ConnectVertexes(vertexNum(i,j),vertexNum(i+1,j),g,g);
			if (j<M-1)
				ConnectVertexes(vertexNum(i,j),vertexNum(i,j+1),g,g);
		}
}

int AddRoute(int source, int target){
	queue<int> W;
	vector<int> prev(Graph.size(),-1);
	vector<int> prevI(Graph.size(),0);
	W.push(source);
	prev[source] = 0;
	while (prev[target]<0 && !W.empty()){
		int current = W.front();
		W.pop();
		for(int i = 0; i<int(Graph[current].size()); ++i)
			if (prev[Graph[current][i].target_vertex]<0 && Graph[current][i].capacity>0){
				prev[Graph[current][i].target_vertex]=current;
				prevI[Graph[current][i].target_vertex]=i;
				W.push(Graph[current][i].target_vertex);
			}
	}
	if (prev[target]<0) 
		return 0;
	int delta = 1000000000;
	int i = target;
	while(i!=source){
		delta=min(delta,Graph[prev[i]][prevI[i]].capacity);
		i = prev[i];
	}
	i = target;
	while(i!=source){
		Graph[prev[i]][prevI[i]].capacity-=delta;
		Graph[i][Graph[prev[i]][prevI[i]].reverse].capacity+=delta;
		i = prev[i];
	}
	return delta;
}

int MaxFlow(){
	int answer = 0;
	int delta;
	while((delta=AddRoute(0,1))>0)
		answer+=delta;
	return answer;
}

int main(){
	ReadData();
	BuildGraph();
	int answer = MaxFlow();
	WriteData(answer);
	return 0;
}