/* gcc_cpp */

/*
 * Problem  :   Drawing
 * Contest  :   UOI-2007 (Kremenchug)
 * Type     :   Solution
 * Date     :   March 29, 2007
 * Version  :   1.1
 * Author   :   Volodymyr Tkachuk
 * Language :   C++
 * Compiler :   GCC 3.4.2
 * Algorithm:   Author Solution (Max flow with Push Pre-flow algorithm with optimizations)
 */
#include <vector>
#include <fstream>
#include <queue>
#include <algorithm>
#include <list>
using namespace std;

const char* inputfile  = "drawing.dat";
const char* outputfile = "drawing.sol";
const int maxN = 100;

struct edge_with_capacity{
	int target_vertex;
	int capacity;
	int reverse;
	edge_with_capacity(int Target, int Capacity, int Reverse){
		target_vertex = Target;
		capacity = Capacity;
		reverse = Reverse;
	}
};

vector<vector<edge_with_capacity> > Graph;
bool field[maxN][maxN];
int N,M,w,b,g;

void ReadData(){
	ifstream in(inputfile);
	in>>N>>M>>w>>b>>g;
	char c;
	for(int i=0; i<N; ++i)
		for(int j=0; j<M; ++j){
			in>>c;
			field[i][j]=(c=='W');
		}
	in.close();
}

void WriteData(int answer){
	ofstream out(outputfile);
	out<<answer<<endl;
	out.close();
}

inline int vertexNum(int i, int j){
	return 2+i*M+j;
}

void ConnectVertexes(int v1, int v2, int c1, int c2){
	edge_with_capacity e1(v2,c1,(int)Graph[v2].size()), e2(v1,c2,(int)Graph[v1].size());
	Graph[v1].push_back(e1);
	Graph[v2].push_back(e2);
}

void BuildGraph(){
	Graph.assign(N*M+2, vector<edge_with_capacity>() );
	for(int i =0; i<N; ++i)
		for(int j = 0; j<M; ++j){
			if (field[i][j])
				ConnectVertexes(vertexNum(i,j),1,b,0);
			else
				ConnectVertexes(0,vertexNum(i,j),w,0);
			if (i<N-1)
				ConnectVertexes(vertexNum(i,j),vertexNum(i+1,j),g,g);
			if (j<M-1)
				ConnectVertexes(vertexNum(i,j),vertexNum(i,j+1),g,g);
		}
}

bool ExistAddRoute(int source, int target){
	queue<int> W;
	vector<int> prev(Graph.size(),-1);
	W.push(source);
	prev[source] = 0;
	while (prev[target]<0 && !W.empty()){
		int current = W.front();
		W.pop();
		for(int i = 0; i<int(Graph[current].size()); ++i)
			if (prev[Graph[current][i].target_vertex]<0 && Graph[current][i].capacity>0){
				prev[Graph[current][i].target_vertex]=current;
				W.push(Graph[current][i].target_vertex);
			}
	}
	return (prev[target]>=0);
}
vector<int> h,e;
list<int> vertex;
void Push(int a, int i){
	int d = min(e[a],Graph[a][i].capacity);
	Graph[a][i].capacity-=d;
	Graph[Graph[a][i].target_vertex][Graph[a][i].reverse].capacity+=d;
	e[a]-=d;
	e[Graph[a][i].target_vertex]+=d;
}
void Lift(int a){
	int n = 1000000000;
	for (int i = 0; i<(int)Graph[a].size(); ++i)
		if (Graph[a][i].capacity>0)
			n=min(n,h[Graph[a][i].target_vertex]);
	h[a]=n+1;
}
void Discharge(int a){
	int i = 0;
	while(e[a]>0){
		if (i==(int) Graph[a].size()){
			Lift(a);
			i=0;
		}
		if (h[a]==h[Graph[a][i].target_vertex]+1)
			Push(a,i);
		++i;
	}
}
int MaxFlow(){
	h.assign(N*M+2,0);
	e.assign(N*M+2,0);
	list<int> L;
	list<int>::iterator current;
	for(int i = 2; i<N*M+2; ++i){
		L.push_back(i);
	}
	do{
		h[0]+=10;
		e[0]=1000000000;
		for(int i = 0; i<(int)Graph[0].size(); ++i){
			Push(0,i);
		}
		current = L.begin();
		while (current!=L.end()){
			if (e[*current]>0){
				Discharge(*current);
				int old = *current;
				L.erase(current);
				L.push_front(old);
				current=L.begin();
			}
			++current;
		}
	}while(ExistAddRoute(0,1));
	return e[1];
}

int main(){
	ReadData();
	BuildGraph();
	int answer = MaxFlow();
	WriteData(answer);
	return 0;
}